package MT::Plugin::SKR::SolidEntryPostTime;
# SolidEntryPostTime - Fixing the post time of entry and webpage
#       Copyright (c) 2008 SKYARC System Co.,Ltd.
#       http://www.skyarc.co.jp/

use strict;
use Data::Dumper;#DEBUG

use vars qw( $MYNAME $VERSION );
$MYNAME = 'SolidEntryPostTime';
$VERSION = '1.01';

use base qw( MT::Plugin );
my $plugin = __PACKAGE__->new({
        name => $MYNAME,
        id => lc $MYNAME,
        key => lc $MYNAME,
        version => $VERSION,
        author_name => 'SKYARC System Co.,Ltd.',
        author_link => 'http://www.skyarc.co.jp/',
#        doc_link = '',
        description => <<HTMLHEREDOC,
<__trans phrase="Fixing the post time of entry and webpage">
HTMLHEREDOC
        l10n_class  => $MYNAME. '::L10N',
        blog_config_template => 'config.tmpl',
        settings => new MT::PluginSettings([
            [ 'fix_time',  { Default => undef, scope => 'blog' } ],
        ]),
});
MT->add_plugin( $plugin );

sub instance { $plugin; }

### Registry
sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'MT::App::CMS::template_source.edit_entry' => \&_edit_entry_source,
            'MT::App::CMS::template_param.edit_entry' => \&_edit_entry_param,
        },
    });
}



###
sub _edit_entry_source {
    my ($eh, $app, $tmpl) = @_;

    my $blog_id = $app->{query}->param( 'blog_id' )
        or return;
    my $fix_time = &instance->get_config_value('fix_time', "blog:$blog_id")
        or return;

    my $old = quotemeta(<<'HTMLHEREDOC');
                <input class="entry-time" name="authored_on_time" tabindex="11" value="<$mt:var name="authored_on_time" escape="html"$>" />
HTMLHEREDOC
    if ($$tmpl !~ /$old/) { # 4.25
        $old = quotemeta(<<'HTMLHEREDOC');
                <input class="entry-time" name="authored_on_time" value="<$mt:var name="authored_on_time" escape="html"$>" />
HTMLHEREDOC
    }
    my $new = <<'HTMLHEREDOC';
                <input class="entry-time" name="authored_on_time" tabindex="11" value="<$mt:var name="authored_on_time" escape="html"$>" readonly="readonly" style="background-color: #ccc;"/>
HTMLHEREDOC
    $$tmpl =~ s/$old/$new/;
}

###
sub _edit_entry_param {
    my ($cb, $app, $param, $tmpl) = @_;

    my $blog_id = $app->{query}->param( 'blog_id' )
        or return;
    my $fix_time = &instance->get_config_value('fix_time', "blog:$blog_id")
        or return;
    my ($th, $tm, $ts) = $fix_time =~ m/(\d\d):(\d\d):(\d\d)/;
    defined $th and defined $tm and defined $ts
        or return;
    $param->{authored_on_time} = $fix_time;

    # for FutureRebuild plugin
    $param->{unpublish_on_time} = $fix_time;
    $param->{unpublish_on_time_readonly} = $fix_time;
}

1;
__END__
